# Welcome to disc2radmc by Dr. Sebastian Marino

Disc2radmc is a python package to create debris disc models that can be fed into RADMC3D to create synthetic images of dust and gas.

## Installation

For now git clone the repository and then add to your path. Pip installation coming soon...

## Usage

See example in [docs/example_dust/Dust_model.ipynb](https://github.com/SebaMarino/disc2radmc/tree/main/docs/example_dust/Dust_model.ipynb) to know how to make images of dust and example at [docs/example_gas/Gas_model.ipynb](https://github.com/SebaMarino/disc2radmc/blob/main/docs/example_gas/Gas_model.ipynb) to make images (cubes) of gas.

## Credits

If you use it for a project please cite Marino et al. 2018, MNRAS, Volume 479, Issue 4, p.5423-5439 (https://ui.adsabs.harvard.edu/abs/2018MNRAS.479.5423M/abstract) and Marino et al. in prep.


